nbxmpp.stringprepare.EmptyMappingTable

Package nbxmpp :: Module stringprepare :: Class EmptyMappingTable |
[hide private]
[frames] | no frames]

# Class EmptyMappingTable

source code

Nested Classes | [hide private]
| __implements__ Interface for character mapping classes

Instance Methods | [hide private]
__init__(self, in_table_function) | source code
map(self, c) | source code

Method Details | [hide private]

### __init__(self, in_table_function) (Constructor) | source code

### map(self, c) | source code